tree_sisters
=================


Installation
--------------

tree_sisters can be installed by unzipping the source code in one directory and using this command: ::

    sudo python setup.py install

You can also install it directly from the Python Package Index with this command: ::

    sudo pip tree_sisters install


Licence
--------

See file LICENCE.txt in this folder


Contribute
-----------
tree_sisters is an open-source software. Everyone is welcome to contribute !
